@@ -1,7 +1,7 @@
 #' Sort rows using dplyr
 #'
-#' `step_arrange` creates a *specification* of a recipe step
-#'  that will sort rows using [dplyr::arrange()].
+#' `step_arrange()` creates a *specification* of a recipe step that will sort
+#' rows using [dplyr::arrange()].
 #'
 #' @inheritParams step_center
 #' @param ... Comma separated list of unquoted variable names.
@@ -22,12 +22,14 @@
 #'  returned. The expressions are text representations and are not
 #'  parsable.
 #'
+#' @template case-weights-not-supported
+#'
 #' @family row operation steps
 #' @family dplyr steps
 #' @export
 #' @examples
-#' rec <- recipe( ~ ., data = iris) %>%
-#'   step_arrange(desc(Sepal.Length), 1/Petal.Length)
+#' rec <- recipe(~., data = iris) %>%
+#'   step_arrange(desc(Sepal.Length), 1 / Petal.Length)
 #'
 #' prepped <- prep(rec, training = iris %>% slice(1:75))
 #' tidy(prepped, number = 1)
@@ -38,7 +40,7 @@
 #'   iris %>%
 #'   as_tibble() %>%
 #'   slice(1:75) %>%
-#'   dplyr::arrange(desc(Sepal.Length), 1/Petal.Length)
+#'   dplyr::arrange(desc(Sepal.Length), 1 / Petal.Length)
 #'
 #' rec_train <- bake(prepped, new_data = NULL)
 #' all.equal(dplyr_train, rec_train)
@@ -47,7 +49,7 @@
 #'   iris %>%
 #'   as_tibble() %>%
 #'   slice(76:150) %>%
-#'   dplyr::arrange(desc(Sepal.Length), 1/Petal.Length)
+#'   dplyr::arrange(desc(Sepal.Length), 1 / Petal.Length)
 #' rec_test <- bake(prepped, iris %>% slice(76:150))
 #' all.equal(dplyr_test, rec_test)
 #'
@@ -58,22 +60,18 @@
 #' sort_vars <- c("Sepal.Length", "Petal.Length")
 #'
 #' qq_rec <-
-#'   recipe( ~ ., data = iris) %>%
+#'   recipe(~., data = iris) %>%
 #'   # Embed the `values` object in the call using !!!
 #'   step_arrange(!!!syms(sort_vars)) %>%
 #'   prep(training = iris)
 #'
 #' tidy(qq_rec, number = 1)
-
-step_arrange <- function(
-  recipe, ...,
-  role = NA,
-  trained = FALSE,
-  inputs = NULL,
-  skip = FALSE,
-  id = rand_id("arrange")
-) {
-
+step_arrange <- function(recipe, ...,
+                         role = NA,
+                         trained = FALSE,
+                         inputs = NULL,
+                         skip = FALSE,
+                         id = rand_id("arrange")) {
   inputs <- enquos(...)
 
   add_step(
