@@ -1,8 +1,7 @@
 #' B-Spline Basis Functions
 #'
-#' `step_bs` creates a *specification* of a recipe step
-#'  that will create new columns that are basis expansions of
-#'  variables using B-splines.
+#' `step_bs()` creates a *specification* of a recipe step that will create new
+#' columns that are basis expansions of variables using B-splines.
 #'
 #' @inheritParams step_pca
 #' @inheritParams step_center
@@ -65,6 +64,7 @@ step_bs <-
            degree = 3,
            objects = NULL,
            options = list(),
+           keep_original_cols = FALSE,
            skip = FALSE,
            id = rand_id("bs")) {
     add_step(
@@ -77,6 +77,7 @@ step_bs <-
         role = role,
         objects = objects,
         options = options,
+        keep_original_cols = keep_original_cols,
         skip = skip,
         id = id
       )
@@ -84,7 +85,8 @@ step_bs <-
   }
 
 step_bs_new <-
-  function(terms, role, trained, deg_free, degree, objects, options, skip, id) {
+  function(terms, role, trained, deg_free, degree, objects, options,
+           keep_original_cols, skip, id) {
     step(
       subclass = "bs",
       terms = terms,
@@ -94,6 +96,7 @@ step_bs_new <-
       degree = degree,
       objects = objects,
       options = options,
+      keep_original_cols = keep_original_cols,
       skip = skip,
       id = id
     )
@@ -157,6 +160,7 @@ prep.step_bs <- function(x, training, info = NULL, ...) {
     degree = x$degree,
     objects = obj,
     options = x$options,
+    keep_original_cols = get_keep_original_cols(x),
     skip = x$skip,
     id = x$id
   )
@@ -164,29 +168,20 @@ prep.step_bs <- function(x, training, info = NULL, ...) {
 
 #' @export
 bake.step_bs <- function(object, new_data, ...) {
-  check_new_data(names(object$objects), object, new_data)
+  col_names <- names(object$objects)
+  check_new_data(col_names, object, new_data)
 
-  ## pre-allocate a matrix for the basis functions.
-  new_cols <- vapply(object$objects, ncol, c(int = 1L))
-  bs_values <-
-    matrix(NA, nrow = nrow(new_data), ncol = sum(new_cols))
-  colnames(bs_values) <- rep("", sum(new_cols))
-  strt <- 1
-  for (i in names(object$objects)) {
-    cols <- (strt):(strt + new_cols[i] - 1)
-    orig_var <- attr(object$objects[[i]], "var")
-    bs_values[, cols] <-
-      bs_predict(object$objects[[i]], new_data[[i]])
-    new_names <-
-      paste(orig_var, "bs", names0(new_cols[i], ""), sep = "_")
-    colnames(bs_values)[cols] <- new_names
-    strt <- max(cols) + 1
-    new_data[[orig_var]] <- NULL
+  for (col_name in col_names) {
+    new_values <- bs_predict(object$objects[[col_name]], new_data[[col_name]])
+
+    new_names <- paste(col_name, "bs", names0(ncol(new_values), ""), sep = "_")
+    colnames(new_values) <- new_names
+
+    new_values <- check_name(new_values, new_data, object, new_names)
+    new_data <- vctrs::vec_cbind(new_data, new_values)
   }
-  bs_values <- as_tibble(bs_values)
-  bs_values <- check_name(bs_values, new_data, object, names(bs_values))
 
-  new_data <- bind_cols(new_data, bs_values)
+  new_data <- remove_original_cols(new_data, object, col_names)
   new_data
 }
 
