@@ -1,10 +1,10 @@
 #' Convert Factors to Strings
 #'
-#' `step_factor2string` will convert one or more factor vectors to strings.
+#' `step_factor2string()` creates a *specification* of a recipe step that will
+#' convert one or more factor vectors to strings.
 #'
 #' @inheritParams step_center
-#' @param columns A character string of variables that will be converted. This
-#'   is `NULL` until computed by [prep()].
+#' @inheritParams step_pca
 #' @template step-return
 #' @family dummy variable and encoding steps
 #' @export
@@ -91,9 +91,12 @@ prep.step_factor2string <- function(x, training, info = NULL, ...) {
 
 #' @export
 bake.step_factor2string <- function(object, new_data, ...) {
-  check_new_data(names(object$columns), object, new_data)
+  col_names <- names(object$columns)
+  check_new_data(col_names, object, new_data)
 
-  new_data[, object$columns] <- map(new_data[, object$columns], as.character)
+  for (col_name in col_names) {
+    new_data[[col_name]] <- as.character(new_data[[col_name]])
+  }
 
   new_data
 }
