@@ -1,8 +1,8 @@
 #' Impute numeric data using the mean
 #'
-#' `step_impute_mean` creates a *specification* of a recipe step that will
-#'  substitute missing values of numeric variables by the training set mean of
-#'  those variables.
+#' `step_impute_mean()` creates a *specification* of a recipe step that will
+#' substitute missing values of numeric variables by the training set mean of
+#' those variables.
 #'
 #' @inheritParams step_center
 #' @param means A named numeric vector of means. This is `NULL` until computed
@@ -186,14 +186,17 @@ prep.step_meanimpute <- prep.step_impute_mean
 
 #' @export
 bake.step_impute_mean <- function(object, new_data, ...) {
-  check_new_data(names(object$means), object, new_data)
+  col_names <- names(object$means)
+  check_new_data(col_names, object, new_data)
 
-  for (i in names(object$means)) {
-    if (any(is.na(new_data[[i]]))) {
-      new_data[[i]] <- vec_cast(new_data[[i]], object$means[[i]])
+  for (col_name in col_names) {
+    mean <- object$means[[col_name]]
+    if (any(is.na(new_data[[col_name]]))) {
+      new_data[[col_name]] <- vctrs::vec_cast(new_data[[col_name]], mean)
     }
-    new_data[is.na(new_data[[i]]), i] <- object$means[[i]]
+    new_data[is.na(new_data[[col_name]]), col_name] <- mean
   }
+
   new_data
 }
 
