@@ -1,8 +1,7 @@
 #' Convert values to predefined integers
 #'
-#' `step_integer` creates a *specification* of a recipe
-#'  step that will convert new data into a set of integers based
-#'  on the original data values.
+#' `step_integer()` creates a *specification* of a recipe step that will convert
+#' new data into a set of integers based on the original data values.
 #'
 #' @inheritParams step_pca
 #' @inheritParams step_center
@@ -112,6 +111,11 @@ get_unique_values <- function(x, zero = FALSE) {
 #' @export
 prep.step_integer <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
+  check_type(
+    training[, col_names],
+    types = c("string", "factor", "ordered", "integer", "double", "logical",
+              "date", "datetime")
+  )
 
   step_integer_new(
     terms = x$terms,
@@ -147,12 +151,18 @@ map_key_to_int <- function(dat, key, strict = FALSE, zero = FALSE) {
 
 #' @export
 bake.step_integer <- function(object, new_data, ...) {
-  check_new_data(names(object$key), object, new_data)
+  col_names <- names(object$key)
+  check_new_data(col_names, object, new_data)
 
-  for (i in names(object$key)) {
-    new_data[[i]] <-
-      map_key_to_int(new_data[[i]], object$key[[i]], object$strict, object$zero_based)
+  for (col_name in col_names) {
+    new_data[[col_name]] <- map_key_to_int(
+      new_data[[col_name]],
+      key = object$key[[col_name]],
+      strict = object$strict,
+      zero = object$zero_based
+    )
   }
+
   new_data
 }
 
