@@ -1,13 +1,12 @@
 #' Inverse Transformation
 #'
-#' `step_inverse` creates a *specification* of a recipe
-#'  step that will inverse transform the data.
+#' `step_inverse()` creates a *specification* of a recipe step that will inverse
+#' transform the data.
 #'
 #' @inheritParams step_center
+#' @inheritParams step_pca
 #' @param offset An optional value to add to the data prior to
 #'  logging (to avoid `1/0`).
-#' @param columns A character string of variable names that will
-#'  be populated (eventually) by the `terms` argument.
 #' @template step-return
 #' @family individual transformation steps
 #' @export
@@ -92,12 +91,13 @@ prep.step_inverse <- function(x, training, info = NULL, ...) {
 
 #' @export
 bake.step_inverse <- function(object, new_data, ...) {
-  check_new_data(names(object$columns), object, new_data)
+  col_names <- names(object$columns)
+  check_new_data(col_names, object, new_data)
 
-  for (i in seq_along(object$columns)) {
-    new_data[[object$columns[i]]] <-
-      1 / (new_data[[object$columns[i]]] + object$offset)
+  for (col_name in col_names) {
+    new_data[[col_name]] <- 1 / (new_data[[col_name]] + object$offset)
   }
+
   new_data
 }
 
