@@ -1,12 +1,10 @@
 #' Inverse Logit Transformation
 #'
-#' `step_invlogit` creates a *specification* of a recipe
-#'  step that will transform the data from real values to be between
-#'  zero and one.
+#' `step_invlogit()` creates a *specification* of a recipe step that will
+#' transform the data from real values to be between zero and one.
 #'
 #' @inheritParams step_center
-#' @param columns A character string of variable names that will
-#'  be populated (eventually) by the `terms` argument.
+#' @inheritParams step_pca
 #' @template step-return
 #' @family individual transformation steps
 #' @export
@@ -87,17 +85,13 @@ prep.step_invlogit <- function(x, training, info = NULL, ...) {
 
 #' @export
 bake.step_invlogit <- function(object, new_data, ...) {
-  check_new_data(names(object$columns), object, new_data)
+  col_names <- names(object$columns)
+  check_new_data(col_names, object, new_data)
 
-  for (i in seq_along(object$columns)) {
-    new_data[[object$columns[i]]] <-
-      binomial()$linkinv(
-        unlist(
-          new_data[[object$columns[i]]],
-          use.names = FALSE
-          )
-      )
+  for (col_name in col_names) {
+    new_data[[col_name]] <- binomial()$linkinv(new_data[[col_name]])
   }
+
   new_data
 }
 
