@@ -1,19 +1,15 @@
 #' Create a lagged predictor
 #'
-#' `step_lag` creates a *specification* of a recipe step that
-#'   will add new columns of lagged data. Lagged data will
-#'   by default include NA values where the lag was induced.
-#'   These can be removed with [step_naomit()], or you may
-#'   specify an alternative filler value with the `default`
-#'   argument.
+#' `step_lag()` creates a *specification* of a recipe step that will add new
+#' columns of lagged data. Lagged data will by default include NA values where
+#' the lag was induced. These can be removed with [step_naomit()], or you may
+#' specify an alternative filler value with the `default` argument.
 #'
 #' @inheritParams step_pca
 #' @inheritParams step_center
 #' @param lag A vector of positive integers. Each specified column will be
 #'  lagged for each value in the vector.
 #' @param prefix A prefix for generated column names, default to "lag_".
-#' @param columns A character string of variable names that will
-#'  be populated (eventually) by the `terms` argument.
 #' @param default Passed to `dplyr::lag`, determines what fills empty rows
 #'   left by lagging (defaults to NA).
 #' @template step-return
@@ -55,6 +51,7 @@ step_lag <-
            prefix = "lag_",
            default = NA,
            columns = NULL,
+           keep_original_cols = TRUE,
            skip = FALSE,
            id = rand_id("lag")) {
     add_step(
@@ -67,6 +64,7 @@ step_lag <-
         default = default,
         prefix = prefix,
         columns = columns,
+        keep_original_cols = keep_original_cols,
         skip = skip,
         id = id
       )
@@ -74,7 +72,8 @@ step_lag <-
   }
 
 step_lag_new <-
-  function(terms, role, trained, lag, default, prefix, columns, skip, id) {
+  function(terms, role, trained, lag, default, prefix, columns,
+           keep_original_cols, skip, id) {
     step(
       subclass = "lag",
       terms = terms,
@@ -84,6 +83,7 @@ step_lag_new <-
       default = default,
       prefix = prefix,
       columns = columns,
+      keep_original_cols = keep_original_cols,
       skip = skip,
       id = id
     )
@@ -91,6 +91,10 @@ step_lag_new <-
 
 #' @export
 prep.step_lag <- function(x, training, info = NULL, ...) {
+  if (!all(x$lag == as.integer(x$lag))) {
+    rlang::abort("step_lag() requires 'lag' argument to be integer-valued.")
+  }
+
   step_lag_new(
     terms = x$terms,
     role = x$role,
@@ -99,6 +103,7 @@ prep.step_lag <- function(x, training, info = NULL, ...) {
     default = x$default,
     prefix = x$prefix,
     columns = recipes_eval_select(x$terms, training, info),
+    keep_original_cols = get_keep_original_cols(x),
     skip = x$skip,
     id = x$id
   )
@@ -106,28 +111,24 @@ prep.step_lag <- function(x, training, info = NULL, ...) {
 
 #' @export
 bake.step_lag <- function(object, new_data, ...) {
-  check_new_data(names(object$columns), object, new_data)
+  col_names <- names(object$columns)
+  check_new_data(col_names, object, new_data)
 
-  if (!all(object$lag == as.integer(object$lag))) {
-    rlang::abort("step_lag requires 'lag' argument to be integer valued.")
-  }
-
-  make_call <- function(col, lag_val) {
-    call2(
-      "lag",
-      x = sym(col),
-      n = lag_val,
-      default = object$default,
-      .ns = "dplyr"
+  for (col_name in col_names) {
+    new_values <- lapply(
+      object$lag,
+      function(x) dplyr::lag(new_data[[col_name]], x, default = object$default)
     )
+
+    new_names <- glue::glue("{object$prefix}{object$lag}_{col_name}")
+    names(new_values) <- new_names
+
+    new_values <- tibble::new_tibble(new_values)
+    new_values <- check_name(new_values, new_data, object, new_names)
+    new_data <- vctrs::vec_cbind(new_data, new_values)
   }
 
-  grid <- tidyr::expand_grid(col = object$columns, lag_val = object$lag)
-  calls <- purrr::map2(grid$col, grid$lag_val, make_call)
-  newname <- as.character(glue("{object$prefix}{grid$lag_val}_{grid$col}"))
-  calls <- check_name(calls, new_data, object, newname, TRUE)
-
-  new_data <- mutate(new_data, !!!calls)
+  new_data <- remove_original_cols(new_data, object, col_names)
   new_data
 }
 
