@@ -1,11 +1,10 @@
 #' Logit Transformation
 #'
-#' `step_logit` creates a *specification* of a recipe
-#'  step that will logit transform the data.
+#' `step_logit()` creates a *specification* of a recipe step that will logit
+#' transform the data.
 #'
 #' @inheritParams step_center
-#' @param columns A character string of variable names that will
-#'  be populated (eventually) by the `terms` argument.
+#' @inheritParams step_pca
 #' @param offset A numeric value to modify values of the columns that are either
 #' one or zero. They are modified to be `x - offset` or `offset`, respectively.
 #' @template step-return
@@ -100,13 +99,13 @@ pre_logit <- function(x, eps = 0) {
 
 #' @export
 bake.step_logit <- function(object, new_data, ...) {
-  check_new_data(names(object$columns), object, new_data)
+  col_names <- names(object$columns)
+  check_new_data(col_names, object, new_data)
 
-  for (i in seq_along(object$columns)) {
-    new_data[[object$columns[i]]] <-
-      binomial()$linkfun(
-        pre_logit(new_data[[object$columns[i]]], object$offset)
-      )
+  for (col_name in col_names) {
+    new_data[[col_name]] <- binomial()$linkfun(
+      pre_logit(new_data[[col_name]], object$offset)
+    )
   }
   new_data
 }
