@@ -1,7 +1,7 @@
 #' Add new variables using dplyr
 #'
-#' `step_mutate()` creates a *specification* of a recipe step
-#'  that will add variables using [dplyr::mutate()].
+#' `step_mutate()` creates a *specification* of a recipe step that will add
+#' variables using [dplyr::mutate()].
 #'
 #' @inheritParams step_pca
 #' @inheritParams step_center
@@ -24,12 +24,14 @@
 #'  `values`, which contains the `mutate()` expressions as character
 #'  strings (and are not reparsable), is returned.
 #'
+#' @template case-weights-not-supported
+#'
 #' @family individual transformation steps
 #' @family dplyr steps
 #' @export
 #' @examples
 #' rec <-
-#'   recipe( ~ ., data = iris) %>%
+#'   recipe(~., data = iris) %>%
 #'   step_mutate(
 #'     dbl_width = Sepal.Width * 2,
 #'     half_length = Sepal.Length / 2
@@ -66,7 +68,7 @@
 #' const <- 1.414
 #'
 #' qq_rec <-
-#'   recipe( ~ ., data = iris) %>%
+#'   recipe(~., data = iris) %>%
 #'   step_mutate(
 #'     bad_approach = Sepal.Width * const,
 #'     best_approach = Sepal.Width * !!const
@@ -77,16 +79,12 @@
 #'
 #' # The difference:
 #' tidy(qq_rec, number = 1)
-
-step_mutate <- function(
-  recipe, ...,
-  role = "predictor",
-  trained = FALSE,
-  inputs = NULL,
-  skip = FALSE,
-  id = rand_id("mutate")
-) {
-
+step_mutate <- function(recipe, ...,
+                        role = "predictor",
+                        trained = FALSE,
+                        inputs = NULL,
+                        skip = FALSE,
+                        id = rand_id("mutate")) {
   inputs <- enquos(...)
 
   add_step(
