@@ -1,8 +1,7 @@
 #' Apply (Smoothed) Rectified Linear Transformation
 #'
-#' `step_relu` creates a *specification* of a recipe step that
-#'   will apply the rectified linear or softplus transformations to numeric
-#'   data. The transformed data is added as new columns to the data matrix.
+#' `step_relu()` creates a *specification* of a recipe step that will add the
+#' rectified linear or softplus transformations of a variable to the data set.
 #'
 #' @inheritParams step_pca
 #' @inheritParams step_center
@@ -14,8 +13,6 @@
 #' @param prefix A prefix for generated column names, defaults to "right_relu_"
 #'   for right hinge transformation and "left_relu_" for reversed/left hinge
 #'   transformations.
-#' @param columns A character string of variable names that will
-#'  be populated (eventually) by the `terms` argument.
 #' @template step-return
 #' @family individual transformation steps
 #' @export
@@ -144,13 +141,15 @@ prep.step_relu <- function(x, training, info = NULL, ...) {
 
 #' @export
 bake.step_relu <- function(object, new_data, ...) {
-  check_new_data(names(object$columns), object, new_data)
+  col_names <- names(object$columns)
+  check_new_data(col_names, object, new_data)
 
   make_relu_call <- function(col) {
     call2("relu", sym(col), object$shift, object$reverse, object$smooth)
   }
-  exprs <- purrr::map(object$columns, make_relu_call)
-  newname <- glue("{object$prefix}{object$columns}")
+
+  exprs <- purrr::map(col_names, make_relu_call)
+  newname <- glue::glue("{object$prefix}{col_names}")
   exprs <- check_name(exprs, new_data, object, newname, TRUE)
   dplyr::mutate(new_data, !!!exprs)
 }
