@@ -1,7 +1,7 @@
 #' Filter rows by position using dplyr
 #'
-#' `step_slice` creates a *specification* of a recipe step
-#'  that will filter rows using [dplyr::slice()].
+#' `step_slice()` creates a *specification* of a recipe step that will filter
+#' rows using [dplyr::slice()].
 #'
 #' @template row-ops
 #' @inheritParams step_center
@@ -20,11 +20,13 @@
 #'  When you [`tidy()`][tidy.recipe()] this step, a tibble with column
 #'  `terms` which contains the filtering indices is returned.
 #'
+#' @template case-weights-not-supported
+#'
 #' @family row operation steps
 #' @family dplyr steps
 #' @export
 #' @examples
-#' rec <- recipe( ~ ., data = iris) %>%
+#' rec <- recipe(~., data = iris) %>%
 #'   step_slice(1:3)
 #'
 #' prepped <- prep(rec, training = iris %>% slice(1:75))
@@ -55,21 +57,18 @@
 #' keep_rows <- 1:6
 #'
 #' qq_rec <-
-#'   recipe( ~ ., data = iris) %>%
+#'   recipe(~., data = iris) %>%
 #'   # Embed `keep_rows` in the call using !!
 #'   step_slice(!!keep_rows) %>%
 #'   prep(training = iris)
 #'
 #' tidy(qq_rec, number = 1)
-step_slice <- function(
-  recipe, ...,
-  role = NA,
-  trained = FALSE,
-  inputs = NULL,
-  skip = TRUE,
-  id = rand_id("slice")
-) {
-
+step_slice <- function(recipe, ...,
+                       role = NA,
+                       trained = FALSE,
+                       inputs = NULL,
+                       skip = TRUE,
+                       id = rand_id("slice")) {
   inputs <- enquos(...)
 
   add_step(
@@ -119,7 +118,7 @@ bake.step_slice <- function(object, new_data, ...) {
 print.step_slice <-
   function(x, width = max(20, options()$width - 35), ...) {
     title <- "Row filtering via position "
-    tr_obj = format_selectors(x$inputs, width)
+    tr_obj <- format_selectors(x$inputs, width)
     print_step(tr_obj, x$inputs, x$trained, title, width)
     invisible(x)
   }
