@@ -290,14 +290,6 @@ test_that("Deprecation warning", {
   )
 })
 
-test_that("printing", {
-  rec <- recipe(sqft ~ ., data = sacr_fac)
-  dummy <- rec %>% step_dummy(city, zip)
-  expect_snapshot(print(dummy))
-  expect_snapshot(prep(dummy))
-})
-
-
 test_that("no columns selected", {
   zdat <- tibble(
     y = c(1, 2, 3),
@@ -320,16 +312,6 @@ test_that("no columns selected", {
   expect_equal(exp_tidy, tidy(rec, number = 2))
 })
 
-test_that("retained columns", {
-  rec <- recipe(sqft ~ zip + city, data = sacr_fac)
-  dummy <- rec %>% step_dummy(city, zip, keep_original_cols = TRUE, id = "")
-  dummy_trained <- prep(dummy, training = sacr_fac)
-  dummy_pred <- bake(dummy_trained, new_data = sacr_fac, all_predictors())
-
-  expect_true(any(colnames(dummy_pred) == "city"))
-  expect_true(any(colnames(dummy_pred) == "zip"))
-})
-
 test_that("check_name() is used", {
   dat <- iris
   dat$Species_versicolor <- dat$Species
@@ -343,35 +325,28 @@ test_that("check_name() is used", {
   )
 })
 
-test_that("keep_original_cols works", {
-  rec <- recipe(sqft ~ city, data = sacr_fac)
-  dummy <- rec %>% step_dummy(city, id = "", keep_original_cols = TRUE)
-  dummy_trained <- prep(dummy, training = sacr_fac, verbose = FALSE)
-  dummy_pred <- bake(dummy_trained, new_data = sacr_fac, all_predictors())
+# Infrastructure ---------------------------------------------------------------
 
-  expect_equal(
-    colnames(dummy_pred),
-    c(
-      "city",
-      paste0("city_", setdiff(gsub(" ", ".", levels(sacr_fac$city)), "ANTELOPE"))
-    )
-  )
+test_that("bake method errors when needed non-standard role columns are missing", {
+  rec <- recipe(sqft ~ zip + city, data = sacr_fac)
+  dummy <- rec %>% step_dummy(city, zip, id = "") %>%
+    update_role(city, zip, new_role = "potato") %>%
+    update_role_requirements(role = "potato", bake = FALSE)
+  dummy_trained <- prep(dummy, training = sacr_fac, verbose = FALSE, strings_as_factors = FALSE)
+
+  expect_error(bake(dummy_trained, new_data = sacr_fac[, 3:4], all_predictors()),
+               class = "new_data_missing_column")
 })
 
-test_that("can prep recipes with no keep_original_cols", {
-  rec <- recipe(sqft ~ city, data = sacr_fac)
-  dummy <- rec %>% step_dummy(city, id = "", keep_original_cols = TRUE)
+test_that("empty printing", {
+  rec <- recipe(mpg ~ ., mtcars)
+  rec <- step_dummy(rec)
 
-  dummy$steps[[1]]$keep_original_cols <- NULL
+  expect_snapshot(rec)
 
-  expect_snapshot(
-    dummy_trained <- prep(dummy, training = sacr_fac, verbose = FALSE)
-  )
+  rec <- prep(rec, mtcars)
 
-  expect_error(
-    dummy_pred <- bake(dummy_trained, new_data = sacr_fac, all_predictors()),
-    NA
-  )
+  expect_snapshot(rec)
 })
 
 test_that("empty selection prep/bake is a no-op", {
@@ -400,25 +375,52 @@ test_that("empty selection tidy method works", {
   expect_identical(tidy(rec, number = 1), expect)
 })
 
-test_that("empty printing", {
-  skip_if(packageVersion("rlang") < "1.0.0")
-  rec <- recipe(mpg ~ ., mtcars)
-  rec <- step_dummy(rec)
+test_that("keep_original_cols works", {
+  new_names <- c("Species_versicolor", "Species_virginica")
 
-  expect_snapshot(rec)
+  rec <- recipe(~ Species, iris) %>%
+    step_dummy(all_predictors(), keep_original_cols = FALSE)
 
-  rec <- prep(rec, mtcars)
+  rec <- prep(rec)
+  res <- bake(rec, new_data = NULL)
 
-  expect_snapshot(rec)
+  expect_equal(
+    colnames(res),
+    new_names
+  )
+
+  rec <- recipe(~ Species, iris) %>%
+    step_dummy(all_predictors(), keep_original_cols = TRUE)
+
+  rec <- prep(rec)
+  res <- bake(rec, new_data = NULL)
+
+  expect_equal(
+    colnames(res),
+    c("Species", new_names)
+  )
 })
 
-test_that("bake method errors when needed non-standard role columns are missing", {
-  rec <- recipe(sqft ~ zip + city, data = sacr_fac)
-  dummy <- rec %>% step_dummy(city, zip, id = "") %>%
-    update_role(city, zip, new_role = "potato") %>%
-    update_role_requirements(role = "potato", bake = FALSE)
-  dummy_trained <- prep(dummy, training = sacr_fac, verbose = FALSE, strings_as_factors = FALSE)
+test_that("keep_original_cols - can prep recipes with it missing", {
+  rec <- recipe(~ Species, iris) %>%
+    step_dummy(all_predictors())
 
-  expect_error(bake(dummy_trained, new_data = sacr_fac[, 3:4], all_predictors()),
-               class = "new_data_missing_column")
+  rec$steps[[1]]$keep_original_cols <- NULL
+
+  expect_snapshot(
+    rec <- prep(rec)
+  )
+
+  expect_error(
+    bake(rec, new_data = iris),
+    NA
+  )
+})
+
+test_that("printing", {
+  rec <- recipe(sqft ~ ., data = sacr_fac) %>%
+    step_dummy(city, zip)
+
+  expect_snapshot(print(rec))
+  expect_snapshot(prep(rec))
 })
