@@ -55,13 +55,6 @@ test_that("check_name() is used", {
   )
 })
 
-test_that("printing", {
-  rec <- recipe(~., data = languages) %>%
-    step_dummy_multi_choice(all_predictors())
-  expect_snapshot(print(rec))
-  expect_snapshot(prep(rec))
-})
-
 test_that("tunable", {
   rec <-
     recipe(~., data = languages) %>%
@@ -77,20 +70,6 @@ test_that("tunable", {
   )
 })
 
-test_that("tunable is setup to work with extract_parameter_set_dials", {
-  skip_if_not_installed("dials")
-  rec <- recipe(~., data = mtcars) %>%
-    step_dummy_multi_choice(
-      all_predictors(),
-      threshold = hardhat::tune()
-    )
-
-  params <- extract_parameter_set_dials(rec)
-
-  expect_s3_class(params, "parameters")
-  expect_identical(nrow(params), 1L)
-})
-
 test_that("no columns selected", {
   zdat <- tibble(
     y = c(1, 2, 3),
@@ -133,6 +112,52 @@ test_that("one columns selected", {
   expect_equal(names(bake(rec, zdat)), c("z", "y", "x_a"))
 })
 
+test_that("factor levels are preserved", {
+  # old data
+  tr <- data.frame(x = factor(c("a", "b", "c"), levels = c("a", "b", "c", "d", "e", "f", "g")))
+
+  # new data
+  te <- data.frame(x = factor(c("c", "d", "e"), levels = c("a", "b", "c", "d", "e", "f", "g")))
+  data1 <- tr %>%
+    recipe() %>%
+    step_dummy(x, one_hot = T) %>%
+    prep() %>%
+    bake(new_data = te)
+
+  data2 <- tr %>%
+    recipe() %>%
+    step_dummy_multi_choice(x, threshold = 0) %>%
+    prep() %>%
+    bake(new_data = te)
+
+  expect_identical(ncol(data1), ncol(data2))
+})
+
+# Infrastructure ---------------------------------------------------------------
+
+test_that("bake method errors when needed non-standard role columns are missing", {
+  rec <- recipe(~., data = languages) %>%
+    step_dummy_multi_choice(lang_1, lang_2, lang_3) %>%
+    update_role(lang_1, new_role = "potato") %>%
+    update_role_requirements(role = "potato", bake = FALSE)
+
+  rec_trained <- prep(rec, training = languages)
+
+  expect_error(bake(rec_trained, new_data = languages[, -1]),
+               class = "new_data_missing_column")
+})
+
+test_that("empty printing", {
+  rec <- recipe(mpg ~ ., mtcars)
+  rec <- step_dummy_multi_choice(rec)
+
+  expect_snapshot(rec)
+
+  rec <- prep(rec, mtcars)
+
+  expect_snapshot(rec)
+})
+
 test_that("empty selection prep/bake is a no-op", {
   rec1 <- recipe(mpg ~ ., mtcars)
   rec2 <- step_dummy_multi_choice(rec1)
@@ -159,35 +184,66 @@ test_that("empty selection tidy method works", {
   expect_identical(tidy(rec, number = 1), expect)
 })
 
-test_that("empty printing", {
-  skip_if(packageVersion("rlang") < "1.0.0")
-  rec <- recipe(mpg ~ ., mtcars)
-  rec <- step_dummy_multi_choice(rec)
+test_that("keep_original_cols works", {
+  new_names <- paste0("lang_1_", c("Armenian", "English", "Spanish"))
 
-  expect_snapshot(rec)
+  rec <- recipe(~ lang_1, data = languages) %>%
+    step_dummy_multi_choice(all_predictors(), keep_original_cols = FALSE)
 
-  rec <- prep(rec, mtcars)
+  rec <- prep(rec)
+  res <- bake(rec, new_data = NULL)
 
-  expect_snapshot(rec)
+  expect_equal(
+    colnames(res),
+    new_names
+  )
+
+  rec <- recipe(~ lang_1, data = languages) %>%
+    step_dummy_multi_choice(all_predictors(), keep_original_cols = TRUE)
+
+  rec <- prep(rec)
+  res <- bake(rec, new_data = NULL)
+
+  expect_equal(
+    colnames(res),
+    c("lang_1", new_names)
+  )
 })
 
-test_that("factor levels are preserved", {
-  # old data
-  tr <- data.frame(x = factor(c("a", "b", "c"), levels = c("a", "b", "c", "d", "e", "f", "g")))
+test_that("keep_original_cols - can prep recipes with it missing", {
+  rec <- recipe(~ lang_1, data = languages) %>%
+    step_dummy_multi_choice(all_predictors())
 
-  # new data
-  te <- data.frame(x = factor(c("c", "d", "e"), levels = c("a", "b", "c", "d", "e", "f", "g")))
-  data1 <- tr %>%
-    recipe() %>%
-    step_dummy(x, one_hot = T) %>%
-    prep() %>%
-    bake(new_data = te)
+  rec$steps[[1]]$keep_original_cols <- NULL
 
-  data2 <- tr %>%
-    recipe() %>%
-    step_dummy_multi_choice(x, threshold = 0) %>%
-    prep() %>%
-    bake(new_data = te)
+  expect_snapshot(
+    rec <- prep(rec)
+  )
 
-  expect_identical(ncol(data1), ncol(data2))
+  expect_error(
+    bake(rec, new_data = languages),
+    NA
+  )
+})
+
+test_that("printing", {
+  rec <- recipe(~., data = languages) %>%
+    step_dummy_multi_choice(all_predictors())
+
+  expect_snapshot(print(rec))
+  expect_snapshot(prep(rec))
+})
+
+test_that("tunable is setup to work with extract_parameter_set_dials", {
+  skip_if_not_installed("dials")
+  rec <- recipe(~., data = mtcars) %>%
+    step_dummy_multi_choice(
+      all_predictors(),
+      threshold = hardhat::tune()
+    )
+
+  params <- extract_parameter_set_dials(rec)
+
+  expect_s3_class(params, "parameters")
+  expect_identical(nrow(params), 1L)
 })
